import os
from pathlib import Path


class ManageBookmark:
    marlin_path = Path((Path.home()) / ".marlin")

    def __init__(self, bookmark_name, bookmark_path, m_path=marlin_path):
        self.bookmark_name = bookmark_name
        self.bookmark_path = bookmark_path
        self.m_path = m_path

    def add_bookmark(self):
        os.chdir(self.m_path)
        with open(self.bookmark_name, "w") as f:
            f.write(self.bookmark_path)

    def remove_bookmark(self):
        os.chdir(self.m_path)
        os.unlink(self.bookmark_name)

    def list_bookmark(self):
        return os.listdir(self.m_path)

    def read_bookmark(self, bookmark):
        os.chdir(self.m_path)
        with open(bookmark, "r") as f:
            return f.read()

    def create_marlin_folder(self):
        exists = Path(self.m_path).exists()
        if not exists:
            (self.m_path).mkdir()



from colorama import init
from colorama import Fore, Style

init(autoreset=True)


def label(label):
    labels = {
        "info": Fore.YELLOW + Style.BRIGHT + "[!]" + Style.RESET_ALL,
        "bad": Fore.RED + Style.BRIGHT + "[-]" + Style.RESET_ALL,
        "good": Fore.GREEN + Style.BRIGHT + "[+]" + Style.RESET_ALL,
        "run": Fore.WHITE + Style.BRIGHT + "[~]" + Style.RESET_ALL,
        "list": Fore.YELLOW + Style.BRIGHT + ">" + Style.RESET_ALL,
    }
    return labels[label]


def color(color, text):
    colors = {
        "yellow": Fore.YELLOW + Style.BRIGHT + text + Style.RESET_ALL,
        "red": Fore.RED + Style.BRIGHT + text + Style.RESET_ALL,
    }
    return colors[color]



from marlin.manage import ManageBookmark
from pathlib import Path

# new test path
marlin_path = Path((Path.home()) / '.test_marlin')
mock_object = ManageBookmark('mock', 'mock_path', marlin_path)


def test_create_marlin_folder():
    mock_object.create_marlin_folder()
    exists = Path(marlin_path).exists()
    # assert exists is True
    if not exists:
        raise AssertionError()


def test_add_bookmark():
    mock_object.add_bookmark()
    bookmark = Path((marlin_path) / 'mock')
    exists = Path(bookmark).exists()
    assert exists is True


def test_read_bookmark():
    mock_path = mock_object.read_bookmark('mock')
    assert mock_path == 'mock_path'


def test_list_bookmark():
    list_bookmark = mock_object.list_bookmark()
    assert isinstance(list_bookmark, list)


def test_remove_bookmark():
    mock_object.remove_bookmark()
    bookmark = Path((marlin_path) / 'mock')
    exists = Path(bookmark).exists()
    # assert exists is False
    if exists is not False:
        raise AssertionError()



from marlin.manage import ManageBookmark
from marlin.styles import label
import click


bookmark_msg = "Bookmark current folder"
rmark_msg = "Remove a bookmar"
marlin_msg = "Swim through the terminal!\n"

commands = {
    "bookmark": f"{label('good')} {'bookmark'.ljust(15)} {bookmark_msg}",
    "rmark": f"{label('bad')} {'rmark'.ljust(15)} {rmark_msg}",
    "marlin": f"{label('run')} {'marlin'.ljust(15)} {marlin_msg}",
}


def main():
    click.echo("Usage: COMMAND [bookmark-name]\n")
    click.echo("Commands:")
    for cmd in commands:
        click.echo(commands[cmd])

    list_bookmarks()


def list_bookmarks():
    bookmark_object = ManageBookmark("mock", "mock")
    all_bookmarks = bookmark_object.list_bookmark()
    click.echo("Saved bookmarks:")
    for bookmark in all_bookmarks:
        bookmark_path = bookmark_object.read_bookmark(bookmark)
        click.echo(f"{label('list')} {bookmark.ljust(17)} {bookmark_path}")


if __name__ == "__main__":
    main()



from marlin.manage import ManageBookmark
from marlin.styles import label, color
from pathlib import Path
import click


@click.command()
@click.argument("bookmark_name")
@click.argument("bookmark_path", default=Path.cwd())
def main(bookmark_name, bookmark_path):
    """
    Bookmark the current folder.
    """
    # create the bookmark object and load the bookmarks
    bookmark_object = ManageBookmark(bookmark_name, str(bookmark_path))
    bookmark_object.create_marlin_folder()
    all_bookmarks = bookmark_object.list_bookmark()

    if bookmark_name in all_bookmarks:
        click.confirm(exist_msg(bookmark_name), abort=True)
    else:
        click.confirm(bookmark_msg(bookmark_name), abort=True)

    # create new bookmark
    bookmark_object.add_bookmark()
    click.echo(bookmarked_msg(bookmark_name))


def exist_msg(bookmark_name):
    msg = "Bookmark already exists. Overwrite"
    return f"\n{label('info')} {msg} {color('yellow', bookmark_name)}?"


def bookmark_msg(bookmark_name):
    msg = "Do you want to bookmark"
    return f"\n{label('info')} {msg} {color('yellow', bookmark_name)}"


def bookmarked_msg(bookmark_name):
    msg = "has been bookmarked."
    return f"{label('good')} {color('yellow', bookmark_name)} {msg}"


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import os
import re

marlin = os.path.join("marlin", "scripts", "marlin.bat")

with open("README.md") as f:
    readme = f.read()


with open("marlin/__init__.py", "r") as file:
    regex_version = r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]'
    version = re.search(regex_version, file.read(), re.MULTILINE).group(1)


setup(
    name="marlin-bookmark",
    version=version,
    description="Swim between bookmarks in the terminal",
    long_description=readme,
    author="Carlos Montecinos Geisse",
    author_email="carlos.w.montecinos@gmail.com",
    url="https://github.com/wilfredinni/marlin",
    license="MIT License",
    packages=find_packages(exclude=("tests", "docs")),
    include_package_data=True,
    install_requires=["click", "colorama"],
    python_requires=">=3",
    scripts=[marlin],
    entry_points={
        "console_scripts": [
            "bookmark = marlin.bookmark:main",
            "rmark = marlin.rmark:main",
            "marlin_help = marlin.marlin_help:main",
        ]
    },
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
)



from marlin.manage import ManageBookmark
from marlin.styles import label, color
import click
import sys


@click.command()
@click.argument("bookmark_name")
def main(bookmark_name):
    """
    Remove a bookmark.
    """
    # create the bookmark instance and load all the bookmarks
    bookmark_object = ManageBookmark(bookmark_name, "mock_path")
    all_bookmarks = bookmark_object.list_bookmark()

    if bookmark_name in all_bookmarks:
        click.confirm(msg_delete(bookmark_name), abort=True)
    else:
        click.echo(msg_not_exist(bookmark_name))
        sys.exit(1)

    # delete the bookmark
    bookmark_object.remove_bookmark()
    click.echo(msg_deleted(bookmark_name))


def msg_delete(bookmark_name):
    msg = "Do you want to delete"
    return f"\n{label('info')} {msg} {color('yellow', bookmark_name)}"


def msg_not_exist(bookmark_name):
    msg = "does not exist."
    return f"\n{label('bad')} {color('yellow', bookmark_name)} {msg}"


def msg_deleted(bookmark_name):
    msg = "has been deleted."
    return f"{label('bad')} {color('yellow', bookmark_name)} {msg}"


if __name__ == "__main__":
    main()
